@@ -16,6 +16,7 @@ class Product(BaseModel):
     ship_day_max: Optional[int]
     ship: Optional[str]
     sold: Optional[str]
+    sold_url_rel: Optional[str]
     offers: Optional[int]
     delivery: Optional[str]
     material: Optional[str]
@@ -31,3 +32,5 @@ class Product(BaseModel):
     review_amount: Optional[int]
     review_star: Optional[float]
     rank: Optional[dict]
+    thumbnail: Optional[str]
+    category: Optional[str]
