@@ -52,6 +52,9 @@ def parse(html: str, p: Product, include: Sequence = None):
     def should_ship_day():
         return "ship_day_min" in include or "ship_day_max" in include
 
+    def should_sold():
+        return "sold" in include or "sold_url_rel" in include
+
     def should_size():
         return "size_length" in include or "size_width" in include or "size_height" in include
 
@@ -68,7 +71,7 @@ def parse(html: str, p: Product, include: Sequence = None):
     "stock" in include and parse_stock(p, selector=sel)
     should_ship_day() and parse_ship_day(p, selector=sel)
     "ship" in include and parse_ship(p, selector=sel)
-    "sold" in include and parse_sold(p, selector=sel)
+    should_sold() and parse_sold(p, selector=sel)
     "offers" in include and parse_offers(p, selector=sel)
     "delivery" in include and parse_delivery(p, selector=sel)
     "material" in include and parse_material(p, selector=sel)
@@ -80,6 +83,8 @@ def parse(html: str, p: Product, include: Sequence = None):
     "review_amount" in include and parse_review_amount(p, selector=sel)
     "review_star" in include and parse_review_star(p, selector=sel)
     "rank" in include and parse_rank(p, selector=sel)
+    "thumbnail" in include and parse_thumbnail(p, selector=sel)
+    "category" in include and parse_category(p, selector=sel)
 
 
 def parse_parent_asin(p: Product, selector: parsel.Selector = None):
@@ -144,6 +149,7 @@ def parse_price(p: Product, selector: parsel.Selector = None):
         s = s or selector.xpath("//div[@id='buyNew_noncbb']/span/text()").get()
         s = s or selector.xpath("//*[@id='color_name_0_price']/span/text()[last()]").get()
         s = s or selector.xpath("//span[@id='sns-base-price']/text()").get()
+        s = s or selector.xpath("//div[@id='olp_feature_div']//span[@class='a-size-base a-color-price']/text()").get()
         return s or ""
 
     def s2() -> str:
@@ -183,6 +189,7 @@ def parse_available(p: Product, selector: parsel.Selector = None):
 
 def parse_in_stock(p: Product, selector: parsel.Selector = None):
     in_stock = selector.xpath("//div[@id='availability']/span/text()").get()
+    in_stock = in_stock or selector.xpath("//div[@id='availability-string']/span/text()").get()
     if in_stock is None:
         p.in_stock = None
         return
@@ -197,6 +204,8 @@ def parse_in_stock(p: Product, selector: parsel.Selector = None):
         p.in_stock = True
     elif in_stock in ["in stock soon.", "currently unavailable.", "temporarily out of stock.", ""]:
         p.in_stock = False
+    elif in_stock.startswith("this item will be released on"):
+        p.in_stock = False
     else:
         p.in_stock = None
 
@@ -226,7 +235,7 @@ def parse_ship_day(p: Product, selector: parsel.Selector = None):
 
 def parse_ship(p: Product, selector: parsel.Selector = None):
     def s1() -> str:
-        return tabular_buy_box_container(selector, "Ships from")
+        return tabular_buy_box_container(selector, "Ships from", "Dispatches from")
 
     def s2() -> str:
         ship = selector.xpath("normalize-space(//div[@id='sfsb_accordion_head']/div/div/span[2]/text())").get()
@@ -249,15 +258,8 @@ def parse_ship(p: Product, selector: parsel.Selector = None):
 
 
 def parse_sold(p: Product, selector: parsel.Selector = None):
-    sold = selector.xpath(
-        "normalize-space(//span[contains(text(), 'Sold by:')]/following-sibling::*[1]/text())"
-    ).get()
-    sold = sold or tabular_buy_box_container(selector, "Sold by")
-    sold = sold or selector.xpath("//a[@id='sellerProfileTriggerId']/text()").get("")
-    if sold == "":
-        p.sold = None
-    else:
-        p.sold = sold
+    p.sold = selector.xpath("//a[@id='sellerProfileTriggerId']/text()").get()
+    p.sold_url_rel = selector.xpath("//a[@id='sellerProfileTriggerId']/@href").get()
 
 
 def parse_offers(p: Product, selector: parsel.Selector = None):
@@ -277,7 +279,7 @@ def parse_delivery(p: Product, selector: parsel.Selector = None):
         p.delivery = None
         return
     if delivery in ["Select delivery location", "Select your address"]:
-        p.delivery = "US"
+        p.delivery = "local"
         return
     if not delivery.startswith("Deliver to"):
         p.delivery = None
@@ -413,11 +415,16 @@ def parse_review_star(p: Product, selector: parsel.Selector = None):
 
 
 def parse_rank(p: Product, selector: parsel.Selector = None):
-    rank = product_details_detail_bullets(selector, "Best Sellers Rank")
+    def s1() -> str:
+        return product_details_detail_bullets(selector, "Best Sellers Rank")
+
+    def s2() -> str:
+        return selector.xpath("normalize-space(string(//span[contains(text(), 'Best Sellers Rank')]/..))").get()
+
+    rank = s1() or s2()
     if rank == "":
         p.rank = None
         return
-
     rank = re.sub(r"\(.*?\)", "", rank)
     rank = re.findall(r"([\d,]+) in ([^\d]+)", rank)
     if len(rank) == 0:
@@ -427,4 +434,24 @@ def parse_rank(p: Product, selector: parsel.Selector = None):
     rank = {r[1].strip(): int(r[0].replace(",", ""))
             for r in rank
             if len(r) == 2 and r[0].replace(",", "").isdigit()}
-    p.rank = rank
+    if len(rank) == 0:
+        p.rank = None
+    else:
+        p.rank = rank
+
+
+def parse_thumbnail(p: Product, selector: parsel.Selector = None):
+    thumbnail = selector.xpath("//div[@id='altImages']//img/@src").re(r"https://m\.media-amazon\.com.+")
+    if len(thumbnail) < 1:
+        p.thumbnail = None
+    else:
+        p.thumbnail = thumbnail[0]
+
+
+def parse_category(p: Product, selector: parsel.Selector = None):
+    category = selector.xpath("normalize-space(//div[@id='nav-subnav']//span[1]/text())").get()
+    category = category or selector.xpath("//div[@id='nav-subnav']//img[1]/@alt").get()
+    if category is None:
+        p.category = None
+    else:
+        p.category = category
